<?php declare(strict_types=1);

/*
 *     Copyleft (C) 2017  http://sikofitt.com sikofitt@gmail.com
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Sikofitt\SamsungTV\Console\Command;

use Sikofitt\SamsungTV\Actions\Actions;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Exception\InvalidArgumentException;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

/**
 * Command to change channels
 */
class ChannelCommand extends Command
{
    /**
     * {@inheritDoc}
     *
     * @throws \Symfony\Component\Console\Exception\InvalidArgumentException
     */
    protected function configure(): void
    {
        $this->setName('channel')
          ->setDescription('change the channel')
          ->addArgument(
              'channel',
              InputArgument::REQUIRED,
              'chanel to change to'
          )
          ->addOption(
              'address',
              'a',
              InputOption::VALUE_OPTIONAL,
              'The IP address of the tv.'
          )
        ;
    }

    /**
     * {@inheritDoc}
     *
     * @throws \Symfony\Component\Console\Exception\InvalidArgumentException
     */
    protected function execute(InputInterface $input, OutputInterface $output): void
    {
        $io = new SymfonyStyle($input, $output);

        $channel = $input->getArgument('channel');
        if ((null === $address = $input->getOption('address')) && (false === $address = getenv('SAMSUNG_IP'))) {
            throw new InvalidArgumentException('Address is required.  You can also set it in the SAMSUNG_IP environment variable.');
        }
        //'10.5.4.18';

        $actions = new Actions($address);
        $off = mb_strtolower($channel);

        if ('off' === $off || 'power' === $off) {
            $actions->powerOff();
        } else {
            $actions->changeChannel($channel);
        }

        $io->success('Changed the Channel to ' . $channel);
    }
}
